@@ -44,7 +44,7 @@ class FleetClient(NamespacedClient):
         Returns the current global checkpoints for an index. This API is design for internal
         use by the fleet server project.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/get-global-checkpoints.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/get-global-checkpoints.html>`_
 
         :param index: A single index or index alias that resolves to a single index.
         :param checkpoints: A comma separated list of previous global checkpoints. When
@@ -489,6 +489,17 @@ class FleetClient(NamespacedClient):
         __path = f"/{_quote(index)}/_fleet/_fleet_search"
         __body: t.Dict[str, t.Any] = {}
         __query: t.Dict[str, t.Any] = {}
+        # The 'sort' parameter with a colon can't be encoded to the body.
+        if sort is not None and (
+            (isinstance(sort, str) and ":" in sort)
+            or (
+                isinstance(sort, (list, tuple))
+                and all(isinstance(_x, str) for _x in sort)
+                and any(":" in _x for _x in sort)
+            )
+        ):
+            __query["sort"] = sort
+            sort = None
         if aggregations is not None:
             __body["aggregations"] = aggregations
         if aggs is not None:
