@@ -42,7 +42,7 @@ class WatcherClient(NamespacedClient):
         """
         Acknowledges a watch, manually throttling the execution of the watch's actions.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-ack-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/watcher-api-ack-watch.html>`_
 
         :param watch_id: Watch ID
         :param action_id: A comma-separated list of the action ids to be acked
@@ -84,7 +84,7 @@ class WatcherClient(NamespacedClient):
         """
         Activates a currently inactive watch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-activate-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/watcher-api-activate-watch.html>`_
 
         :param watch_id: Watch ID
         """
@@ -120,7 +120,7 @@ class WatcherClient(NamespacedClient):
         """
         Deactivates a currently active watch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-deactivate-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/watcher-api-deactivate-watch.html>`_
 
         :param watch_id: Watch ID
         """
@@ -156,7 +156,7 @@ class WatcherClient(NamespacedClient):
         """
         Removes a watch from Watcher.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-delete-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/watcher-api-delete-watch.html>`_
 
         :param id: Watch ID
         """
@@ -210,12 +210,11 @@ class WatcherClient(NamespacedClient):
         """
         Forces the execution of a stored watch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-execute-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/watcher-api-execute-watch.html>`_
 
         :param id: Identifier for the watch.
         :param action_modes: Determines how to handle the watch actions as part of the
-            watch execution. See [Action execution modes](https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-execute-watch.html#watcher-api-execute-watch-action-mode)
-            for more information.
+            watch execution.
         :param alternative_input: When present, the watch uses this object as a payload
             instead of executing its own input.
         :param debug: Defines whether the watch runs in debug mode.
@@ -228,9 +227,9 @@ class WatcherClient(NamespacedClient):
         :param simulated_actions:
         :param trigger_data: This structure is parsed as the data of the trigger event
             that will be used during the watch execution
-        :param watch: When present, this [watch](https://www.elastic.co/guide/en/elasticsearch/reference/current/how-watcher-works.html#watch-definition)
-            is used instead of the one specified in the request. This watch is not persisted
-            to the index and record_execution cannot be set.
+        :param watch: When present, this watch is used instead of the one specified in
+            the request. This watch is not persisted to the index and record_execution
+            cannot be set.
         """
         if id not in SKIP_IN_PATH:
             __path = f"/_watcher/watch/{_quote(id)}/_execute"
@@ -286,7 +285,7 @@ class WatcherClient(NamespacedClient):
         """
         Retrieves a watch by its ID.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-get-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/watcher-api-get-watch.html>`_
 
         :param id: Watch ID
         """
@@ -335,7 +334,7 @@ class WatcherClient(NamespacedClient):
         """
         Creates a new watch, or updates an existing one.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-put-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/watcher-api-put-watch.html>`_
 
         :param id: Watch ID
         :param actions:
@@ -431,7 +430,7 @@ class WatcherClient(NamespacedClient):
         """
         Retrieves stored watches.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-query-watches.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/watcher-api-query-watches.html>`_
 
         :param from_: The offset from the first result to fetch. Needs to be non-negative.
         :param query: Optional, query filter watches to be returned.
@@ -443,6 +442,17 @@ class WatcherClient(NamespacedClient):
         __path = "/_watcher/_query/watches"
         __query: t.Dict[str, t.Any] = {}
         __body: t.Dict[str, t.Any] = {}
+        # The 'sort' parameter with a colon can't be encoded to the body.
+        if sort is not None and (
+            (isinstance(sort, str) and ":" in sort)
+            or (
+                isinstance(sort, (list, tuple))
+                and all(isinstance(_x, str) for _x in sort)
+                and any(":" in _x for _x in sort)
+            )
+        ):
+            __query["sort"] = sort
+            sort = None
         if error_trace is not None:
             __query["error_trace"] = error_trace
         if filter_path is not None:
@@ -484,7 +494,7 @@ class WatcherClient(NamespacedClient):
         """
         Starts Watcher if it is not already running.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-start.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/watcher-api-start.html>`_
         """
         __path = "/_watcher/_start"
         __query: t.Dict[str, t.Any] = {}
@@ -539,7 +549,7 @@ class WatcherClient(NamespacedClient):
         """
         Retrieves the current Watcher metrics.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/watcher-api-stats.html>`_
 
         :param metric: Defines which additional metrics are included in the response.
         :param emit_stacktraces: Defines whether stack traces are generated for each
@@ -579,7 +589,7 @@ class WatcherClient(NamespacedClient):
         """
         Stops Watcher if it is running.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/watcher-api-stop.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/watcher-api-stop.html>`_
         """
         __path = "/_watcher/_stop"
         __query: t.Dict[str, t.Any] = {}
