@@ -50,7 +50,7 @@ class TextStructureClient(NamespacedClient):
         Finds the structure of a text file. The text file must contain data that is suitable
         to be ingested into Elasticsearch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/find-structure.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/find-structure.html>`_
 
         :param text_files:
         :param charset: The text’s character set. It must be a character set that is
